@@ -1,15 +1,22 @@
 import os
 import time
 
+try:
+    from invoke.vendor.six import StringIO
+except ImportError:
+    from six import StringIO
+
 from invoke import pty_size, CommandTimedOut
+from invocations.environment import in_ci
 from pytest import skip, raises
+from pytest_relaxed import trap
 
 from fabric import Connection, Config
 
 
 # TODO: use pytest markers
-def skip_outside_travis():
-    if not os.environ.get("TRAVIS", False):
+def skip_outside_ci():
+    if not in_ci():
         skip()
 
 
@@ -56,6 +63,20 @@ class Connection_:
             assert "\r\n" in result.stdout
             assert result.pty is True
 
+    class shell:
+        @trap
+        def base_case(self):
+            result = Connection("localhost").shell(
+                # Some extra newlines to make sure it doesn't get split up by
+                # motd/prompt
+                in_stream=StringIO("\n\nexit\n")
+            )
+            assert result.command is None
+            assert "exit" in result.stdout
+            assert result.stderr == ""
+            assert result.exited == 0
+            assert result.pty is True
+
     class local:
         def wraps_invoke_run(self):
             # NOTE: most of the interesting tests about this are in
@@ -91,14 +112,14 @@ class Connection_:
             """
             Run command via sudo on host localhost
             """
-            skip_outside_travis()
+            skip_outside_ci()
             assert self.cxn.sudo("whoami").stdout.strip() == "root"
 
         def mixed_sudo_and_normal_commands(self):
             """
             Run command via sudo, and not via sudo, on localhost
             """
-            skip_outside_travis()
+            skip_outside_ci()
             logname = os.environ["LOGNAME"]
             assert self.cxn.run("whoami").stdout.strip() == logname
             assert self.cxn.sudo("whoami").stdout.strip() == "root"
